[−][src]Type Definition bio_seq_algos::utils::FxHashMap
type FxHashMap<K, V> = HashMap<K, V, BuildHasherDefault<FxHasher>>;
Type alias for a hashmap using the fx hash algorithm.
type FxHashMap<K, V> = HashMap<K, V, BuildHasherDefault<FxHasher>>;
Type alias for a hashmap using the fx hash algorithm.